# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum
from aliro_quantum.api.circuit_api import CircuitApi  # noqa: E501
from aliro_quantum.rest import ApiException


class TestCircuitApi(unittest.TestCase):
    """CircuitApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum.api.circuit_api.CircuitApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_circuit_translation_post(self):
        """Test case for circuit_translation_post

        translates circuits into other quantum languages  # noqa: E501
        """
        pass

    def test_circuit_visualization_get(self):
        """Test case for circuit_visualization_get

        """
        pass

    def test_circuit_visualization_post(self):
        """Test case for circuit_visualization_post

        converts a Quil circuit into a PNG image  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
