# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum
from aliro_quantum.api.submissions_api import SubmissionsApi  # noqa: E501
from aliro_quantum.rest import ApiException


class TestSubmissionsApi(unittest.TestCase):
    """SubmissionsApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum.api.submissions_api.SubmissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_submissions_delete(self):
        """Test case for submissions_delete

        delete submissions  # noqa: E501
        """
        pass

    def test_submissions_get(self):
        """Test case for submissions_get

        get all user's submissions  # noqa: E501
        """
        pass

    def test_submissions_post(self):
        """Test case for submissions_post

        submit a new submission  # noqa: E501
        """
        pass

    def test_submissions_rename_post(self):
        """Test case for submissions_rename_post

        rename submission  # noqa: E501
        """
        pass

    def test_submissions_submission_name_get(self):
        """Test case for submissions_submission_name_get

        get submissions  # noqa: E501
        """
        pass

    def test_submissions_submission_name_stream_get(self):
        """Test case for submissions_submission_name_stream_get

        Stream submission updates. Valid event types to listen for are:   - SUBMISSION_DETAIL_UPDATED   - SUBMISSION_DETAIL_COMPLETED   # noqa: E501
        """
        pass

    def test_submissions_summary_stream_get(self):
        """Test case for submissions_summary_stream_get

        Stream submissions summary. Possible event types:    - SUBMISSION_SUMMARY_UPDATED   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
