# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class DeviceDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active_reset_fidelity': 'float',
        'depth_one_circuit_time': 'float',
        'device_id': 'str',
        'display_name': 'str',
        'gate_info': 'DeviceDetailsGateInfo',
        'gates': 'list[Gate]',
        'initialization_time': 'float',
        'is_simulator': 'bool',
        'jobs_queue_size': 'int',
        'last_calibration': 'str',
        'max_shots': 'int',
        'next_available_time': 'str',
        'price': 'float',
        'quantum_volume': 'int',
        'qubits': 'dict(str, Qubit)',
        'supports_mid_circuit_measurement': 'bool',
        't1': 'float',
        't2': 'float'
    }

    attribute_map = {
        'active_reset_fidelity': 'activeResetFidelity',
        'depth_one_circuit_time': 'depthOneCircuitTime',
        'device_id': 'deviceId',
        'display_name': 'displayName',
        'gate_info': 'gateInfo',
        'gates': 'gates',
        'initialization_time': 'initializationTime',
        'is_simulator': 'isSimulator',
        'jobs_queue_size': 'jobsQueueSize',
        'last_calibration': 'lastCalibration',
        'max_shots': 'maxShots',
        'next_available_time': 'nextAvailableTime',
        'price': 'price',
        'quantum_volume': 'quantumVolume',
        'qubits': 'qubits',
        'supports_mid_circuit_measurement': 'supportsMidCircuitMeasurement',
        't1': 't1',
        't2': 't2'
    }

    def __init__(self, active_reset_fidelity=None, depth_one_circuit_time=None, device_id=None, display_name=None, gate_info=None, gates=None, initialization_time=None, is_simulator=None, jobs_queue_size=None, last_calibration=None, max_shots=None, next_available_time=None, price=None, quantum_volume=None, qubits=None, supports_mid_circuit_measurement=None, t1=None, t2=None, local_vars_configuration=None):  # noqa: E501
        """DeviceDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active_reset_fidelity = None
        self._depth_one_circuit_time = None
        self._device_id = None
        self._display_name = None
        self._gate_info = None
        self._gates = None
        self._initialization_time = None
        self._is_simulator = None
        self._jobs_queue_size = None
        self._last_calibration = None
        self._max_shots = None
        self._next_available_time = None
        self._price = None
        self._quantum_volume = None
        self._qubits = None
        self._supports_mid_circuit_measurement = None
        self._t1 = None
        self._t2 = None
        self.discriminator = None

        if active_reset_fidelity is not None:
            self.active_reset_fidelity = active_reset_fidelity
        if depth_one_circuit_time is not None:
            self.depth_one_circuit_time = depth_one_circuit_time
        if device_id is not None:
            self.device_id = device_id
        if display_name is not None:
            self.display_name = display_name
        if gate_info is not None:
            self.gate_info = gate_info
        if gates is not None:
            self.gates = gates
        if initialization_time is not None:
            self.initialization_time = initialization_time
        if is_simulator is not None:
            self.is_simulator = is_simulator
        if jobs_queue_size is not None:
            self.jobs_queue_size = jobs_queue_size
        if last_calibration is not None:
            self.last_calibration = last_calibration
        if max_shots is not None:
            self.max_shots = max_shots
        if next_available_time is not None:
            self.next_available_time = next_available_time
        if price is not None:
            self.price = price
        if quantum_volume is not None:
            self.quantum_volume = quantum_volume
        if qubits is not None:
            self.qubits = qubits
        if supports_mid_circuit_measurement is not None:
            self.supports_mid_circuit_measurement = supports_mid_circuit_measurement
        if t1 is not None:
            self.t1 = t1
        if t2 is not None:
            self.t2 = t2

    @property
    def active_reset_fidelity(self):
        """Gets the active_reset_fidelity of this DeviceDetails.  # noqa: E501


        :return: The active_reset_fidelity of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._active_reset_fidelity

    @active_reset_fidelity.setter
    def active_reset_fidelity(self, active_reset_fidelity):
        """Sets the active_reset_fidelity of this DeviceDetails.


        :param active_reset_fidelity: The active_reset_fidelity of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._active_reset_fidelity = active_reset_fidelity

    @property
    def depth_one_circuit_time(self):
        """Gets the depth_one_circuit_time of this DeviceDetails.  # noqa: E501


        :return: The depth_one_circuit_time of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._depth_one_circuit_time

    @depth_one_circuit_time.setter
    def depth_one_circuit_time(self, depth_one_circuit_time):
        """Sets the depth_one_circuit_time of this DeviceDetails.


        :param depth_one_circuit_time: The depth_one_circuit_time of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._depth_one_circuit_time = depth_one_circuit_time

    @property
    def device_id(self):
        """Gets the device_id of this DeviceDetails.  # noqa: E501


        :return: The device_id of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this DeviceDetails.


        :param device_id: The device_id of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def display_name(self):
        """Gets the display_name of this DeviceDetails.  # noqa: E501


        :return: The display_name of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this DeviceDetails.


        :param display_name: The display_name of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def gate_info(self):
        """Gets the gate_info of this DeviceDetails.  # noqa: E501


        :return: The gate_info of this DeviceDetails.  # noqa: E501
        :rtype: DeviceDetailsGateInfo
        """
        return self._gate_info

    @gate_info.setter
    def gate_info(self, gate_info):
        """Sets the gate_info of this DeviceDetails.


        :param gate_info: The gate_info of this DeviceDetails.  # noqa: E501
        :type: DeviceDetailsGateInfo
        """

        self._gate_info = gate_info

    @property
    def gates(self):
        """Gets the gates of this DeviceDetails.  # noqa: E501


        :return: The gates of this DeviceDetails.  # noqa: E501
        :rtype: list[Gate]
        """
        return self._gates

    @gates.setter
    def gates(self, gates):
        """Sets the gates of this DeviceDetails.


        :param gates: The gates of this DeviceDetails.  # noqa: E501
        :type: list[Gate]
        """

        self._gates = gates

    @property
    def initialization_time(self):
        """Gets the initialization_time of this DeviceDetails.  # noqa: E501


        :return: The initialization_time of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._initialization_time

    @initialization_time.setter
    def initialization_time(self, initialization_time):
        """Sets the initialization_time of this DeviceDetails.


        :param initialization_time: The initialization_time of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._initialization_time = initialization_time

    @property
    def is_simulator(self):
        """Gets the is_simulator of this DeviceDetails.  # noqa: E501


        :return: The is_simulator of this DeviceDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_simulator

    @is_simulator.setter
    def is_simulator(self, is_simulator):
        """Sets the is_simulator of this DeviceDetails.


        :param is_simulator: The is_simulator of this DeviceDetails.  # noqa: E501
        :type: bool
        """

        self._is_simulator = is_simulator

    @property
    def jobs_queue_size(self):
        """Gets the jobs_queue_size of this DeviceDetails.  # noqa: E501


        :return: The jobs_queue_size of this DeviceDetails.  # noqa: E501
        :rtype: int
        """
        return self._jobs_queue_size

    @jobs_queue_size.setter
    def jobs_queue_size(self, jobs_queue_size):
        """Sets the jobs_queue_size of this DeviceDetails.


        :param jobs_queue_size: The jobs_queue_size of this DeviceDetails.  # noqa: E501
        :type: int
        """

        self._jobs_queue_size = jobs_queue_size

    @property
    def last_calibration(self):
        """Gets the last_calibration of this DeviceDetails.  # noqa: E501


        :return: The last_calibration of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._last_calibration

    @last_calibration.setter
    def last_calibration(self, last_calibration):
        """Sets the last_calibration of this DeviceDetails.


        :param last_calibration: The last_calibration of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._last_calibration = last_calibration

    @property
    def max_shots(self):
        """Gets the max_shots of this DeviceDetails.  # noqa: E501


        :return: The max_shots of this DeviceDetails.  # noqa: E501
        :rtype: int
        """
        return self._max_shots

    @max_shots.setter
    def max_shots(self, max_shots):
        """Sets the max_shots of this DeviceDetails.


        :param max_shots: The max_shots of this DeviceDetails.  # noqa: E501
        :type: int
        """

        self._max_shots = max_shots

    @property
    def next_available_time(self):
        """Gets the next_available_time of this DeviceDetails.  # noqa: E501


        :return: The next_available_time of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._next_available_time

    @next_available_time.setter
    def next_available_time(self, next_available_time):
        """Sets the next_available_time of this DeviceDetails.


        :param next_available_time: The next_available_time of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._next_available_time = next_available_time

    @property
    def price(self):
        """Gets the price of this DeviceDetails.  # noqa: E501


        :return: The price of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this DeviceDetails.


        :param price: The price of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def quantum_volume(self):
        """Gets the quantum_volume of this DeviceDetails.  # noqa: E501


        :return: The quantum_volume of this DeviceDetails.  # noqa: E501
        :rtype: int
        """
        return self._quantum_volume

    @quantum_volume.setter
    def quantum_volume(self, quantum_volume):
        """Sets the quantum_volume of this DeviceDetails.


        :param quantum_volume: The quantum_volume of this DeviceDetails.  # noqa: E501
        :type: int
        """

        self._quantum_volume = quantum_volume

    @property
    def qubits(self):
        """Gets the qubits of this DeviceDetails.  # noqa: E501


        :return: The qubits of this DeviceDetails.  # noqa: E501
        :rtype: dict(str, Qubit)
        """
        return self._qubits

    @qubits.setter
    def qubits(self, qubits):
        """Sets the qubits of this DeviceDetails.


        :param qubits: The qubits of this DeviceDetails.  # noqa: E501
        :type: dict(str, Qubit)
        """

        self._qubits = qubits

    @property
    def supports_mid_circuit_measurement(self):
        """Gets the supports_mid_circuit_measurement of this DeviceDetails.  # noqa: E501


        :return: The supports_mid_circuit_measurement of this DeviceDetails.  # noqa: E501
        :rtype: bool
        """
        return self._supports_mid_circuit_measurement

    @supports_mid_circuit_measurement.setter
    def supports_mid_circuit_measurement(self, supports_mid_circuit_measurement):
        """Sets the supports_mid_circuit_measurement of this DeviceDetails.


        :param supports_mid_circuit_measurement: The supports_mid_circuit_measurement of this DeviceDetails.  # noqa: E501
        :type: bool
        """

        self._supports_mid_circuit_measurement = supports_mid_circuit_measurement

    @property
    def t1(self):
        """Gets the t1 of this DeviceDetails.  # noqa: E501


        :return: The t1 of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._t1

    @t1.setter
    def t1(self, t1):
        """Sets the t1 of this DeviceDetails.


        :param t1: The t1 of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._t1 = t1

    @property
    def t2(self):
        """Gets the t2 of this DeviceDetails.  # noqa: E501


        :return: The t2 of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._t2

    @t2.setter
    def t2(self, t2):
        """Sets the t2 of this DeviceDetails.


        :param t2: The t2 of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._t2 = t2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceDetails):
            return True

        return self.to_dict() != other.to_dict()
