# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum
from aliro_quantum.api.user_api import UserApi  # noqa: E501
from aliro_quantum.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_api_key_post(self):
        """Test case for user_api_key_post

        generate Aliro API key for user  # noqa: E501
        """
        pass

    def test_user_information_update_post(self):
        """Test case for user_information_update_post

        update user email and name  # noqa: E501
        """
        pass

    def test_user_password_change_post(self):
        """Test case for user_password_change_post

        change user password from known password  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
